        function getF(rr,cc){
       if(rr==5 && cc==0){return '../../SIN/066/cl0_tz_500.png';}
       if(rr==5 && cc==1){return '../../SIN/066/cl1_tz_500.png';}
       if(rr==5 && cc==2){return '../../SIN/066/cl2_tz_500.png';}
       if(rr==5 && cc==3){return '../../SIN/066/cl3_tz_500.png';}
       if(rr==40 && cc==0){return 'prob_tcc_thr0_cl0.png';}
       if(rr==40 && cc==1){return 'prob_tcc_thr0_cl1.png';}
       if(rr==40 && cc==2){return 'prob_tcc_thr0_cl2.png';}
       if(rr==40 && cc==3){return 'prob_tcc_thr0_cl3.png';}
       if(rr==41 && cc==0){return 'prob_tcc_thr2_cl0.png';}
       if(rr==41 && cc==1){return 'prob_tcc_thr2_cl1.png';}
       if(rr==41 && cc==2){return 'prob_tcc_thr2_cl2.png';}
       if(rr==41 && cc==3){return 'prob_tcc_thr2_cl3.png';}
       if(rr==42 && cc==0){return 'prob_tcc_thr4_cl0.png';}
       if(rr==42 && cc==1){return 'prob_tcc_thr4_cl1.png';}
       if(rr==42 && cc==2){return 'prob_tcc_thr4_cl2.png';}
       if(rr==42 && cc==3){return 'prob_tcc_thr4_cl3.png';}
       if(rr==43 && cc==0){return 'prob_tcc_thr7_cl0.png';}
       if(rr==43 && cc==1){return 'prob_tcc_thr7_cl1.png';}
       if(rr==43 && cc==2){return 'prob_tcc_thr7_cl2.png';}
       if(rr==43 && cc==3){return 'prob_tcc_thr7_cl3.png';}
}
