        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 25 <strong>control</strong><br>0,2,4,8,9,10,11,14,16,17,19,21,26,30,34,36,37,39,41,43,45,46,47,48,49';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 14 <br>1,3,5,6,7,15,22,23,25,27,32,33,35,42';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 12 <br>12,13,18,20,24,28,29,31,38,40,44,50';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 25 <strong>control</strong><br>0,2,4,8,9,10,11,14,16,17,19,21,26,30,34,36,37,39,41,43,45,46,47,48,49';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 14 <br>1,3,5,6,7,15,22,23,25,27,32,33,35,42';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 12 <br>12,13,18,20,24,28,29,31,38,40,44,50';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 25 <strong>control</strong><br>0,2,4,8,9,10,11,14,16,17,19,21,26,30,34,36,37,39,41,43,45,46,47,48,49';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 14 <br>1,3,5,6,7,15,22,23,25,27,32,33,35,42';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 12 <br>12,13,18,20,24,28,29,31,38,40,44,50';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 25 <strong>control</strong><br>0,2,4,8,9,10,11,14,16,17,19,21,26,30,34,36,37,39,41,43,45,46,47,48,49';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 14 <br>1,3,5,6,7,15,22,23,25,27,32,33,35,42';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 12 <br>12,13,18,20,24,28,29,31,38,40,44,50';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 25 <strong>control</strong><br>0,2,4,8,9,10,11,14,16,17,19,21,26,30,34,36,37,39,41,43,45,46,47,48,49';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 14 <br>1,3,5,6,7,15,22,23,25,27,32,33,35,42';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 12 <br>12,13,18,20,24,28,29,31,38,40,44,50';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 25 <strong>control</strong><br>0,2,4,8,9,10,11,14,16,17,19,21,26,30,34,36,37,39,41,43,45,46,47,48,49';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 14 <br>1,3,5,6,7,15,22,23,25,27,32,33,35,42';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260511 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 12 <br>12,13,18,20,24,28,29,31,38,40,44,50';}
}
